@@ -41,7 +41,8 @@ class Manager:
             self.service.properties['maintenance_in_progress'] = None
             # update service
             self.query_helper.update(
-                model=self.service
+                model=self.service,
+                audit=False
             )
         del self.query_helper
         del self.redis_helper
@@ -75,7 +76,8 @@ class Manager:
             self.service.properties['maintenance_in_progress'] = self.engine_slug
 
             self.query_helper.update(
-                model=self.service
+                model=self.service,
+                audit=False
             )
 
         return allow_maintenance
