@@ -74,6 +74,9 @@ class MaintenanceManager:
         self.solution_state_manager = SolutionStateManager()
         self.campaign_state_manager = CampaignStateManager()
         self.dataset_state_manager = DatasetStateManager()
+        process = self.query_helper.get_process(slug='sagemaker-maintenance')
+        if process is not None:
+            self.query_helper.process_id = process.id
 
     def __del__(self):
         # finally close query helper
@@ -87,7 +90,8 @@ class MaintenanceManager:
             self.service.properties['maintenance_in_progress'] = None
             # update service
             self.query_helper.update(
-                model=self.service
+                model=self.service,
+                audit=False
             )
         del self.query_helper
 
@@ -120,7 +124,8 @@ class MaintenanceManager:
             self.service.properties['maintenance_in_progress'] = self.engine_slug
 
             self.query_helper.update(
-                model=self.service
+                model=self.service,
+                audit=False
             )
 
         return allow_maintenance
